@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQHTTP_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QHttp class
-// For Qt3, no changes are needed
-
 #include <ntqhttp.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QHttp class
-// For Qt4, some changes are needed
-
-#include <Qt/q3http.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQHTTP_H */
